@@ -1,4 +1,4 @@
-/* $Id: gtkmm.h,v 1.8 2004/04/11 21:00:53 murrayc Exp $ */
+/* $Id: gtkmm.h,v 1.9 2004/05/19 00:12:22 daniel Exp $ */
 /* gtkmm - a C++ wrapper for the Gtk toolkit
  *
  * Copyright 1999-2002 The gtkmm Development Team
@@ -51,7 +51,8 @@ extern const int gtkmm_micro_version;
 #include <gtkmm/colorselection.h>
 #include <gtkmm/combo.h> //TODO: Deprecated.
 #include <gtkmm/combobox.h>
-#include <gtkmm/combobox.h>
+#include <gtkmm/comboboxentry.h>
+#include <gtkmm/comboboxentrytext.h>
 #include <gtkmm/comboboxtext.h>
 #include <gtkmm/container.h>
 #include <gtkmm/curve.h>
