@@ -1,5 +1,5 @@
 // -*- c++ -*-
-/* $Id: stock.cc,v 1.1.1.1 2003/01/21 13:40:58 murrayc Exp $ */
+/* $Id: stock.cc,v 1.3 2004/04/11 21:00:53 murrayc Exp $ */
 
 /* Copyright (C) 2002 The gtkmm Development Team
  *
@@ -20,6 +20,7 @@
 
 #include <gtkmm/stock.h>
 #include <gtkmm/stockitem.h>
+#include <gtk/gtkstock.h>
 
 // Get rid of macro DELETE (from winnt.h).  We have some macro
 // shadowing magic in stock.h, but it's safer to get rid of it
@@ -33,6 +34,7 @@ namespace Gtk
 namespace Stock
 {
 
+const Gtk::BuiltinStockID DIALOG_AUTHENTICATION = { GTK_STOCK_DIALOG_AUTHENTICATION };
 const Gtk::BuiltinStockID DIALOG_INFO = { GTK_STOCK_DIALOG_INFO };
 const Gtk::BuiltinStockID DIALOG_WARNING = { GTK_STOCK_DIALOG_WARNING };
 const Gtk::BuiltinStockID DIALOG_ERROR = { GTK_STOCK_DIALOG_ERROR };
