@@ -2,11 +2,11 @@
 #ifndef _GTKMM_TARGETENTRY_H
 #define _GTKMM_TARGETENTRY_H
 
-/* $Id: targetentry.h,v 1.5 2002/06/22 15:26:26 murrayc Exp $ */
+/* $Id: targetentry.h,v 1.3 2004/04/11 21:00:53 murrayc Exp $ */
 
 /* targetentry.h
  *
- * Copyright (C) 2001 The Gtk-- Development Team
+ * Copyright (C) 2002 The gtkmm Development Team
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -26,8 +26,16 @@
 #include <glibmm/utility.h>
 #include <glibmm/ustring.h>
 #include <glibmm/arrayhandle.h>
+#include <gtkmm/enums.h>
 #include <gtk/gtkselection.h> //For GtkTargetEntry.
 
+#ifndef DOXYGEN_SHOULD_SKIP_THIS
+extern "C"
+{
+  typedef struct _GtkTargetEntry GtkTargetEntry;
+}
+#endif /* DOXYGEN_SHOULD_SKIP_THIS */
+
 namespace Gtk
 {
 
@@ -35,7 +43,7 @@ class TargetEntry
 {
 public:
   TargetEntry();
-  explicit TargetEntry(const Glib::ustring& target, guint flags = 0, guint info = 0);
+  explicit TargetEntry(const Glib::ustring& target, Gtk::TargetFlags flags = Gtk::TargetFlags(0), guint info = 0);
   explicit TargetEntry(const GtkTargetEntry& gobject);
   TargetEntry(const TargetEntry& src);
   virtual ~TargetEntry();
@@ -45,8 +53,8 @@ public:
   Glib::ustring get_target() const;
   void set_target(const Glib::ustring& target);
 
-  guint get_flags() const;
-  void set_flags(guint flags);
+  Gtk::TargetFlags get_flags() const;
+  void set_flags(Gtk::TargetFlags flags);
 
   guint get_info() const;
   void set_info(guint info);
